@@ -89,7 +89,6 @@ sub read2 {
                 $ssh2->_set_error(Net::SSH2::LIBSSH2_ERROR_TIMEOUT(), "Time out waiting for data");
                 return;
             }
-            return if $deadline and time > $deadline;
             my $sock = $ssh2->sock;
             my $fn = fileno($sock);
             my ($rbm, $wbm) = ('', '');
@@ -101,11 +100,17 @@ sub read2 {
     }
 }
 
+my $readline_non_blocking_warned;
 sub readline {
     my ($self, $ext, $eol) = @_;
     return if $self->eof;
     $ext ||= 0;
     $eol = $/ unless @_ >= 3;
+
+    $self->blocking or $readline_non_blocking_warned++ or
+        warnings::warnif('Net::SSH2',
+                         "Calling Net::SSH2::Channel::readline in non-blocking mode is usually a programming error");
+
     if (wantarray or not defined $eol) {
         my $data = '';
         my $buffer;
@@ -502,8 +507,9 @@ limitation in libssh2.
 
 =head2 flush ( [ ext ] )
 
-Flushes the channel; if C<ext> is present and set, flushes extended
-data channel. Returns number of bytes flushed, C<undef> on error.
+Discards the received but still unread data on the channel; if C<ext>
+is present and set, discards data on the extended channel. Returns
+number of bytes discarded, C<undef> on error.
 
 =head2 exit_signal
 
